# TransportOrderStatusEnum

* `draft` - Draft * `new` - New * `approaching_origin` - Approaching origin * `approaching_destination` - Approaching destination * `in_destination` - In destination * `accepted` - Accepted * `cancelled` - Cancelled

## Enum

* `DRAFT` (value: `'draft'`)

* `NEW` (value: `'new'`)

* `APPROACHING_ORIGIN` (value: `'approaching_origin'`)

* `APPROACHING_DESTINATION` (value: `'approaching_destination'`)

* `IN_DESTINATION` (value: `'in_destination'`)

* `ACCEPTED` (value: `'accepted'`)

* `CANCELLED` (value: `'cancelled'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


